@@ -12,7 +12,6 @@ class Util(object):
         self.is_win = 'window' in platform.system().lower()
         self.is_wsl = 'linux' in platform.system().lower() and 'microsoft' in platform.release().lower()  # 判断当前是不是WSL环境
         self.is_py2 = sys.version_info < (3, 0)
-        self.adb_path = ''
         self.sn = sn
         self.debug = False
         if sn is None:
@@ -84,18 +83,10 @@ class Util(object):
             print('执行命令超时 {}s: {}'.format(timeout, arg))
 
     def adb(self, arg, timeout=30, encoding='utf-8'):
-        if self.adb_path == '' and self.is_wsl:  # 适配 wsl2 中使用 win10 中的adb情况
-            out = Util.cmd('whereis adb')
-            if 'adb:' in out:
-                out = out.replace('adb:', '').strip().split(' /')[0]  # 使用第一个 path
-                if 'adb' in out:
-                    self.adb_path = '"{}"'.format(out)  # 防止有空格，加上双引号
-        self.adb_path = self.adb_path if self.adb_path else 'adb'
-
         if self.sn:
-            arg = '{} -s {} {}'.format(self.adb_path, self.sn, arg)
+            arg = 'adb -s {} {}'.format(self.sn, arg)
         else:
-            arg = '{} {}'.format(self.adb_path, arg)
+            arg = 'adb {}'.format(arg)
         return self.cmd(arg, timeout, encoding=encoding)
 
     def shell(self, arg, timeout=30, encoding='utf-8'):
